% pushd -- add a directory to the stack.
%
%      pushd(dir)
%
% Add the directory DIR to the top of the directory stack making
% the new top of the stack the current working directory.  With
% no arguments, exchanges the top two directories.
%
% You can see the directory stack with the 'dirs' command.
%
% See also: popd, dirs

%% pushd.m --- the preceding comment is the documentation string.

% Copyright (C) 2000--2011 Ralph Schleicher

% Author: Ralph Schleicher <rs@ralph-schleicher.de>

% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation, either version 3 of
% the license, or (at your option) any later version.

% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.

% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

% Additional permission under GNU GPL version 3 section 7

% If you modify this program, or any covered work, by linking or
% combining it with MATLAB from The Mathworks, Inc. (or a modified
% version of MATLAB), containing parts covered by the same license
% as MATLAB, the licensors of this program grant you additional
% permission to convey the resulting work.

%% Code:

% Program entry point.
function pushd(dir)

  d = dir_stack;
  if nargin == 0
    if numel(d) < 2
      error('No other directory');
    end
    dir = d{2};
    try
      cd(dir);
      d{2} = d{1};
      d{1} = dir;
    catch
      warning(sprintf('Can not change to directory ''%s''', dir));
      d(2) = [];
    end
  else
    try
      cd(dir);
      d = {dir, d{:}};
    catch
      warning(sprintf('Can not change to directory ''%s''', dir));
    end
  end
  dir_stack(d);

  dirs;

%% pushd.m ends here
